"""
Organizations sub-app for django-clerk-users.

This is an optional sub-app that provides organization support.
To use it, add 'django_clerk_users.organizations' to INSTALLED_APPS.
"""

default_app_config = "django_clerk_users.organizations.apps.OrganizationsConfig"
